#ifndef _GroupFile_H_
#define _GroupFile_H_

#include "stdafx.h"
#include "fileformatdefs.h"
#include <stdio.h>
#include "linkedlist.h"

/*! This class is used to deal with GRP files. */
class GroupFile
{
public:
	/*! Load a GroupFile from disk */
	GroupFile(const char* filename);

	/*! Create an empty GroupFile */
	GroupFile();

	/*!  */
	~GroupFile();

	/*! Load a Groupfile */
	int Load();

	/*! Save the group file */
	int Save();	

	/*! Set the filename for the GroupFile */
	void SetFilename(const char* sFilename);
	
	/*! Get the filename of the GroupFile */
	char*  GetFileName(){ return m_sFileName; }

	/*! Get the number of file in this GroupFile */
	uint32 GetNumFiles(){ return m_nNumFiles; }

	/*! Get a particular file entry. If the requested entry is outside the bounds
		of the array, \b NULL is returned.
	*/
	FILESTRUCT* GetFileEntry(uint32 nEntry)
	{
		if(nEntry >= m_nNumFiles)
		{
			return NULL;
		}else
		{
			return &m_Files[nEntry];
		}
	}

	/*! Add a file to the Group File. Do not forget that the filename is to be 8.3 */
	ErrorCode AddFile(char* sFilename);

	/*! Remove an entry from the Group File by filename */
	ErrorCode RemoveFile(char* sFilename);

	/*!
		Return the current status of the Groupfile. This is used to find out
		if any errors occured during the loading of a GroupFile.
	*/
	int GetStatus(){ return m_nStatus; }

protected:

	int Open(const char* sFlags);
	int Close();

	/*! Filename of the GroupFile */
	char m_sFileName[256];

	/*! Author name of the GroupFile format. This should always be set to KENSILVERMAN. */
	char m_sAuthorName[12];

	/*! Total number of files in the GroupFile archive */
	uint32 m_nNumFiles;	

	/*! File data */
	//FILESTRUCT* m_Files;
	LinkedList<FILESTRUCT> m_Files;

	/*! File pointer for the current GroupFile */
	FILE *m_pFilePointer;

	/*! Current status of the GroupFile */
	int	m_nStatus;
	
};

#endif
